PyGranta |version|
##################

Welcome to the PyGranta project. This page lists the PyAnsys packages
that provide integration with Granta MI services.

.. toctree::
   :hidden:
   :maxdepth: 3

   getting_started
   user_guide
   api
   examples
   package_versions
   development_and_release_processes

.. grid:: 3

    .. grid-item-card:: PyGranta BoM Analytics :material-regular:`science` :material-regular:`eco`
      :padding: 2 2 2 2
      :link: https://bomanalytics.grantami.docs.pyansys.com/
      :class-title: pyansys-card-title

      Sustainability and restricted substance analysis.

    .. grid-item-card:: PyGranta RecordLists :material-regular:`list`
      :padding: 2 2 2 2
      :link: https://recordlists.grantami.docs.pyansys.com/
      :class-title: pyansys-card-title

      Manage favorite Granta MI materials in Python as record lists.

    .. grid-item-card:: PyGranta JobQueue :material-regular:`work_history`
      :padding: 2 2 2 2
      :link: https://jobqueue.grantami.docs.pyansys.com/
      :class-title: pyansys-card-title

      Import and export text and Excel data with Python asynchronously.

    .. grid-item-card:: PyGranta System :material-regular:`settings`
      :padding: 2 2 2 2
      :link: https://system.grantami.docs.pyansys.com/
      :class-title: pyansys-card-title

      Access Granta MI system functions.

    .. grid-item-card:: PyGranta Data Flow Extensions :material-regular:`fork_right`
      :padding: 2 2 2 2
      :link: https://dataflow-extensions.grantami.docs.pyansys.com/
      :class-title: pyansys-card-title

      Interoperability between Granta MI Data Flow and Python.
